@@ -128,9 +128,8 @@ class FBProphet(BaseModel):
             dataframes with actual and predicted values
         """
         df = dataframe.rename(columns={DATE_COLUMN_NAME: "ds", VALUE_COLUMN_NAME: "y"})
-        df["y"] = np.log(df["y"])
 
-        model = Prophet(yearly_seasonality=10)
+        model = Prophet(yearly_seasonality=20)
         model.fit(df, iter=1000)
 
         future = model.make_future_dataframe(periods=len(forecast_period_list), freq=frequency)
@@ -142,8 +141,8 @@ class FBProphet(BaseModel):
         df_forecast = df_forecast[df_forecast[VALUE_COLUMN_NAME].isnull()]
 
         actual_values = df_train[VALUE_COLUMN_NAME]
-        predicted_values = np.exp(df_train["yhat"])
-        forecasted_values = np.exp(df_forecast["yhat"])
+        predicted_values = df_train["yhat"]
+        forecasted_values = df_forecast["yhat"]
 
         return actual_values, predicted_values, forecasted_values
 
@@ -166,7 +165,7 @@ class FBNeuralProphet(BaseModel):
         """
         df = dataframe.rename(columns={DATE_COLUMN_NAME: "ds", VALUE_COLUMN_NAME: "y"})
 
-        model = NeuralProphet(yearly_seasonality=10)
+        model = NeuralProphet(yearly_seasonality=30)
         model.fit(df=df, freq=frequency)
 
         future = model.make_future_dataframe(
@@ -323,11 +322,12 @@ class XGBoost(BaseModel):
     def create_time_series_features(self, time_series_df, frequency, backtest=False):
         result_df = time_series_df.copy()
         if frequency == "W-MON":
-            self.PREVIOUS_PERIODS = 53
-            result_df["year"] = result_df.index.year
-            result_df["period_number"] = result_df.index.isocalendar().week.astype(str)
+            self.PREVIOUS_PERIODS = 57
+            period_index = result_df.index
+            result_df["year"] = period_index.year
+            result_df["period_number"] = period_index.isocalendar().week.astype(str)
         else:
-            self.PREVIOUS_PERIODS = 12
+            self.PREVIOUS_PERIODS = 13
             result_df["period_number"] = result_df.index.month.astype(str)
         previous_periods = self.PREVIOUS_PERIODS
         if backtest:
@@ -419,10 +419,13 @@ class XGBoost(BaseModel):
         backfill_dataframe = pd.concat([original_dataframe, backfill_dataframe]).sort_values(by="period")
         backfill_dataframe = backfill_dataframe.set_index("period").asfreq(frequency)
 
-        # Parse original dataframe for usage later
-        dataframe = original_dataframe.set_index("period").asfreq(frequency)
-
         # Prepare dataframe
+        # Decompose time series
+        decomposed_dataframe = utils.get_seasonal_decomposition(backfill_dataframe["y"])
+        decomposed_dataframe = decomposed_dataframe.asfreq(frequency)
+
+        # Create Time Series Features for stationary
+        backfill_dataframe = pd.DataFrame(decomposed_dataframe.rename(columns={"seasonal": "y"})["y"])
         dataframe_backtest = self.create_time_series_features(backfill_dataframe, frequency, backtest=True)
 
         predicted = []
@@ -448,11 +451,28 @@ class XGBoost(BaseModel):
             # add actual observation to history for the next loop
             train = pd.concat([train, pd.DataFrame(row).T])
 
-        # Run full forecast
-        dataframe_forecast = self.create_time_series_features(dataframe, frequency, backtest=False)
+        # Add in trend and combine
+        backtest_output = pd.merge(left=test, right=decomposed_dataframe, how="left", right_index=True, left_index=True)
+        backtest_output[VALUE_COLUMN_NAME] = backtest_output[VALUE_COLUMN_NAME] * backtest_output["trend"]
+        backtest_output["seasonal_predicted"] = predicted
+        backtest_output["predicted"] = backtest_output["trend"] * backtest_output["seasonal_predicted"]
+
+        # Run full seasonal forecast
+        dataframe_forecast = self.create_time_series_features(backfill_dataframe, frequency, backtest=False)
         forecast_predictions = self.full_forecast(dataframe_forecast, feature_columns, forecast_period_list, frequency)
 
-        return test[VALUE_COLUMN_NAME], predicted, forecast_predictions
+        # Make trend predictions
+        trend_history = decomposed_dataframe[~decomposed_dataframe["trend"].isnull()]
+        trend_history = trend_history.reset_index(drop=True)["trend"]
+        linear_predictions = utils.get_linear_predictions(trend_history, [i for i in range(0, len(forecast_period_list))])
+        assembled_forecast = pd.DataFrame({
+            "period": forecast_period_list,
+            "linear": linear_predictions.values,
+            "seasonal": forecast_predictions.values
+        })
+        assembled_forecast.set_index("period", inplace=True)
+
+        return backtest_output[VALUE_COLUMN_NAME], backtest_output["predicted"], assembled_forecast["linear"] * assembled_forecast["seasonal"]
 
 
 class RandomForest(BaseModel):
@@ -467,11 +487,12 @@ class RandomForest(BaseModel):
     def create_time_series_features(self, time_series_df, frequency, backtest=False):
         result_df = time_series_df.copy()
         if frequency == "W-MON":
-            self.PREVIOUS_PERIODS = 53
-            result_df["year"] = result_df.index.year
-            result_df["period_number"] = result_df.index.isocalendar().week.astype(str)
+            self.PREVIOUS_PERIODS = 57
+            period_index = result_df.index
+            result_df["year"] = period_index.year
+            result_df["period_number"] = period_index.isocalendar().week.astype(str)
         else:
-            self.PREVIOUS_PERIODS = 12
+            self.PREVIOUS_PERIODS = 13
             result_df["period_number"] = result_df.index.month.astype(str)
         previous_periods = self.PREVIOUS_PERIODS
         if backtest:
@@ -563,10 +584,13 @@ class RandomForest(BaseModel):
         backfill_dataframe = pd.concat([original_dataframe, backfill_dataframe]).sort_values(by="period")
         backfill_dataframe = backfill_dataframe.set_index("period").asfreq(frequency)
 
-        # Parse original dataframe for usage later
-        dataframe = original_dataframe.set_index("period").asfreq(frequency)
-
         # Prepare dataframe
+        # Decompose time series
+        decomposed_dataframe = utils.get_seasonal_decomposition(backfill_dataframe["y"])
+        decomposed_dataframe = decomposed_dataframe.asfreq(frequency)
+
+        # Create Time Series Features for stationary
+        backfill_dataframe = pd.DataFrame(decomposed_dataframe.rename(columns={"seasonal": "y"})["y"])
         dataframe_backtest = self.create_time_series_features(backfill_dataframe, frequency, backtest=True)
 
         predicted = []
@@ -591,12 +615,28 @@ class RandomForest(BaseModel):
 
             # add actual observation to history for the next loop
             train = pd.concat([train, pd.DataFrame(row).T])
+        # Add in trend and combine
+        backtest_output = pd.merge(left=test, right=decomposed_dataframe, how="left", right_index=True, left_index=True)
+        backtest_output[VALUE_COLUMN_NAME] = backtest_output[VALUE_COLUMN_NAME] * backtest_output["trend"]
+        backtest_output["seasonal_predicted"] = predicted
+        backtest_output["predicted"] = backtest_output["trend"] * backtest_output["seasonal_predicted"]
 
-        # Run full forecast
-        dataframe_forecast = self.create_time_series_features(dataframe, frequency, backtest=False)
+        # Run full seasonal forecast
+        dataframe_forecast = self.create_time_series_features(backfill_dataframe, frequency, backtest=False)
         forecast_predictions = self.full_forecast(dataframe_forecast, feature_columns, forecast_period_list, frequency)
 
-        return test[VALUE_COLUMN_NAME], predicted, forecast_predictions
+        # Make trend predictions
+        trend_history = decomposed_dataframe[~decomposed_dataframe["trend"].isnull()]
+        trend_history = trend_history.reset_index(drop=True)["trend"]
+        linear_predictions = utils.get_linear_predictions(trend_history, [i for i in range(0, len(forecast_period_list))])
+        assembled_forecast = pd.DataFrame({
+            "period": forecast_period_list,
+            "linear": linear_predictions.values,
+            "seasonal": forecast_predictions.values
+        })
+        assembled_forecast.set_index("period", inplace=True)
+
+        return backtest_output[VALUE_COLUMN_NAME], backtest_output["predicted"], assembled_forecast["linear"] * assembled_forecast["seasonal"]
 
 
 class SARIMA(BaseModel):
